@@ -1164,7 +1164,7 @@ def sim_ancestry(
         the :ref:`sec_ancestry_models_specifying` section for more details,
         and the :ref:`sec_ancestry_models` section for the available models
         and examples.
-    :type model: str or .AncestryModel or list
+    :type model: str or msprime.AncestryModel or list
     :return: The :class:`tskit.TreeSequence` object representing the results
         of the simulation if no replication is performed, or an
         iterator over the independent replicates simulated if the
@@ -1915,9 +1915,10 @@ class SweepGenicSelection(ParametricAncestryModel):
     Thus fitness of the heterozygote is intermediate to the
     two homozygotes.
 
-    .. warning:: Currently, models where `start_frequency` is
+    .. warning:: Models where `start_frequency` is
        :math:`\\geq \\frac{1}{ploidy*N}`
-       will give incorrect results.  In practical terms, this issue means
+       will not simulate the trajectory until its origination.
+       In practical terms, this issue means
        that "sweeps from neutral standing genetic variation" are currently not
        possible. The tracking issue for this on GitHub is
        `here <https://github.com/tskit-dev/msprime/issues/1762>`_.
